@@ -62,7 +62,7 @@ qUUID <- function(n = 1) {
   # n: number of uuids to return
   # value: n RFC 1422 conforming, random UUIDs
 
-  if(!curl::has_internet()){
+  if(!curl::has_internet() | check_qrng() < 0){
     cat("The ANU Quantum Random Number Generator service is not available at [https://qrng.anu.edu.au/index.php].\nAre you connected to the internet?\n")
   }else{
 
